@@ -12,7 +12,7 @@ from sphinx.application import Sphinx
 from sphinx.util.fileutil import copy_asset_file
 
 from sphinx_carousel import __version__, nodes
-from sphinx_carousel.directives import Carousel
+from sphinx_carousel.directives import Carousel, FigureCarousel
 
 CONF_DEFAULT_BOOTSTRAP_ADD_CSS_JS = True
 CONF_DEFAULT_BOOTSTRAP_PREFIX = "scbs-"
@@ -38,8 +38,8 @@ def copy_static(app: Sphinx):
     static_out.mkdir(exist_ok=True)
 
     if app.config.carousel_bootstrap_add_css_js:
-        copy_asset_file(str(static_in / "bootstrap-carousel.css"), str(static_out))
-        copy_asset_file(str(static_in / "bootstrap-carousel.js"), str(static_out))
+        copy_asset_file(str(static_in / "bootstrap-carousel.min.css"), str(static_out))
+        copy_asset_file(str(static_in / "bootstrap-carousel.min.js"), str(static_out))
 
     context = {
         "bootstrap_prefix": app.config["carousel_bootstrap_prefix"],
@@ -60,8 +60,8 @@ def include_static_on_demand(app: Sphinx, _: str, __: str, ___: dict, doctree: d
         return
 
     if app.config.carousel_bootstrap_add_css_js:
-        app.add_css_file("bootstrap-carousel.css")
-        app.add_js_file("bootstrap-carousel.js")
+        app.add_css_file("bootstrap-carousel.min.css")
+        app.add_js_file("bootstrap-carousel.min.js")
 
     app.add_css_file("carousel-custom.css")
 
@@ -83,6 +83,7 @@ def setup(app: Sphinx) -> Dict[str, str]:
     app.add_config_value("carousel_show_indicators", CONF_DEFAULT_SHOW_INDICATORS, "html")
     app.add_config_value("carousel_show_shadows", CONF_DEFAULT_SHOW_SHADOWS, "html")
     app.add_directive("carousel", Carousel)
+    app.add_directive("figure-carousel", FigureCarousel)
     app.connect("builder-inited", copy_static)
     app.connect("html-page-context", include_static_on_demand)
     nodes.CarouselCaptionNode.add_node(app)
